// Importing necessary libraries for drawing the world map.
import {
  select,
  json,
  csv,
  geoPath,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';
//Creating a svg.
const svg = select('svg');
//Using the projection.
const projection = geoMercator()
  .translate([-1800, 1100])
  .scale([1600]);
//Generating a path around states.
const pathGenerator = geoPath().projection(projection);
//Using a color scheme.
const colorScale = scaleOrdinal(schemeCategory10);
//Reading a .json file from gist.
json(
  'https://gist.githubusercontent.com/ubl2/c32cce5cbad8ed0e3cf5b83d245fa650/raw/46f57493a33086dcf425c1e1220cb08adb792108/india.json'
).then((data) => {
  const countryShapes = feature(
    data,
    data.objects.IND_adm1
  );
countryShapes.features.shift()
//Defining the attributes of svg for path.
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('fill', (d) => colorScale(d.properties.NAME_1))
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);
//Defining the attributes of svg for text.
svg
  .selectAll('text')
  .data(countryShapes.features)
  .enter()
  .append('text')
  .text((d) => d.properties.NAME_1)
  .attr('x', d=>  pathGenerator.centroid(d)[0]   )
  .attr('y',d=>pathGenerator.centroid(d)[1])
    .attr("text-anchor", "middle")
   .attr("font-size", "16px");
});